<img src="https://leitor-pdf.readthedocs.io/en/latest/assets/logo_doc_python.jpg" width=200>

# Leitor de PDF
Varias bibliotecas de extração de texto de pdf reunidas em um unico modulos



## Como instalar

```
pip install leitor_pdf
```